<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<defaultcodec></defaultcodec>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/aboutdialog.cpp" line="82"/>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/aboutdialog.cpp" line="68"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/aboutdialog.cpp" line="69"/>
        <source>Unable to launch external application.
</source>
        <translation>無法啟動外部應用程式。
</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/aboutdialog.cpp" line="70"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkdialog.ui" line="19"/>
        <source>Add Bookmark</source>
        <translation>新增書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkdialog.ui" line="29"/>
        <source>Bookmark:</source>
        <translation>書籤：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkdialog.ui" line="36"/>
        <source>Add in Folder:</source>
        <translation>新增到資料夾：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkdialog.ui" line="93"/>
        <source>New Folder</source>
        <translation>新增資料夾</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="268"/>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkdialog.ui" line="65"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="199"/>
        <source>Delete Folder</source>
        <translation>刪除資料夾</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="200"/>
        <source>Rename Folder</source>
        <translation>重命名資料夾</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="646"/>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="682"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="684"/>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>您打算刪除資料夾，這會將裡面的內容&lt;br&gt;一併移除。您確定要繼續嗎？</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="800"/>
        <source>New Folder</source>
        <translation>新資料夾</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/bookmarkwidget.cpp" line="198"/>
        <source>Bookmarks</source>
        <translation type="obsolete">書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="440"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/bookmarkwidget.cpp" line="167"/>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation type="obsolete">您打算刪除資料夾，這會將裡面的內容一併移除。您確定要繼續嗎？</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="363"/>
        <source>Delete Folder</source>
        <translation>刪除資料夾</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="364"/>
        <source>Rename Folder</source>
        <translation>重命名資料夾</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="366"/>
        <source>Show Bookmark</source>
        <translation>顯示書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="367"/>
        <source>Show Bookmark in New Tab</source>
        <translation>於新分頁顯示書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="370"/>
        <source>Delete Bookmark</source>
        <translation>刪除書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="371"/>
        <source>Rename Bookmark</source>
        <translation>重命名書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="409"/>
        <source>Search for:</source>
        <translation>搜尋字串：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="431"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="164"/>
        <source>Add new page</source>
        <translation>新增頁面</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="173"/>
        <source>Close current page</source>
        <translation>關閉目前的頁面</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="435"/>
        <source>Print Document</source>
        <translation>列印文件</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="565"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="640"/>
        <source>Add New Page</source>
        <translation>新增頁面</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="641"/>
        <source>Close This Page</source>
        <translation>關閉此頁面</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="642"/>
        <source>Close Other Pages</source>
        <translation>關閉其他頁面</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="644"/>
        <source>Add Bookmark for this Page...</source>
        <translation>將此頁面新增到書籤...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="871"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/contentwindow.cpp" line="113"/>
        <source>Open Link</source>
        <translation>開啟連結</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/contentwindow.cpp" line="114"/>
        <source>Open Link in New Tab</source>
        <translation>在新分頁開啟連結</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/filternamedialog.ui" line="13"/>
        <source>FilterNameDialog</source>
        <translation type="obsolete">過濾器名稱對話框</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/filternamedialog.ui" line="25"/>
        <source>Filter Name:</source>
        <translation>過濾器名稱：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/filternamedialog.ui" line="13"/>
        <source>Add Filter Name</source>
        <translation>新增過濾器名稱</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="83"/>
        <source>Previous</source>
        <translation>前一個</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="90"/>
        <source>Next</source>
        <translation>下一個</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="95"/>
        <source>Case Sensitive</source>
        <translation>區分大小寫</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="98"/>
        <source>Whole words</source>
        <translation>整個單字</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/centralwidget.cpp" line="110"/>
        <source>&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;&amp;nbsp;搜尋已過盡頭</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <location filename="../tools/shared/fontpanel/fontpanel.cpp" line="35"/>
        <source>Font</source>
        <translation>字型</translation>
    </message>
    <message>
        <location filename="../tools/shared/fontpanel/fontpanel.cpp" line="46"/>
        <source>&amp;Writing system</source>
        <translation>手寫系統(&amp;W)</translation>
    </message>
    <message>
        <location filename="../tools/shared/fontpanel/fontpanel.cpp" line="49"/>
        <source>&amp;Family</source>
        <translation>家族(&amp;W)</translation>
    </message>
    <message>
        <location filename="../tools/shared/fontpanel/fontpanel.cpp" line="53"/>
        <source>&amp;Style</source>
        <translation>樣式(&amp;S)</translation>
    </message>
    <message>
        <location filename="../tools/shared/fontpanel/fontpanel.cpp" line="57"/>
        <source>&amp;Point size</source>
        <translation>點大小(&amp;P)</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/helpviewer.cpp" line="270"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/helpviewer.cpp" line="256"/>
        <source>Unable to launch web browser.
</source>
        <translation type="obsolete">無法啟動瀏覽器。
</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/helpviewer.cpp" line="272"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/helpviewer.cpp" line="290"/>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;錯誤 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;找不到頁面&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/helpviewer.cpp" line="378"/>
        <source>Copy &amp;Link Location</source>
        <translation>複製連結位置(&amp;L)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/helpviewer.cpp" line="381"/>
        <source>Open Link in New Tab<byte value="x9"/>Ctrl+LMB</source>
        <translation>在新分頁開啟連結<byte value="x9"/>Ctrl+滑鼠左鍵</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/helpviewer.cpp" line="169"/>
        <source>Open Link in New Tab</source>
        <translation>在新分頁開啟連結</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/helpviewer.cpp" line="271"/>
        <source>Unable to launch external application.
</source>
        <translation>無法啟動外部應用程式。
</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/indexwindow.cpp" line="38"/>
        <source>&amp;Look for:</source>
        <translation>搜尋(&amp;L)：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/indexwindow.cpp" line="105"/>
        <source>Open Link</source>
        <translation>開啟連結</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/indexwindow.cpp" line="106"/>
        <source>Open Link in New Tab</source>
        <translation>在新分頁開啟連結</translation>
    </message>
</context>
<context>
    <name>InstallDialog</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.ui" line="13"/>
        <source>Install Documentation</source>
        <translation>安裝文件</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="77"/>
        <source>Downloading documentation info...</source>
        <translation>下載文件資訊中...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="125"/>
        <source>Download canceled.</source>
        <translation>下載已取消。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="256"/>
        <source>Done.</source>
        <translation>完成。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="167"/>
        <source>The file %1 already exists. Do you want to overwrite it?</source>
        <translation>檔案 %1 已存在。您要覆寫它嗎？</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="178"/>
        <source>Unable to save the file %1: %2.</source>
        <translation>無法儲存檔案 %1：%2。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="185"/>
        <source>Downloading %1...</source>
        <translation>下載 %1 中...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="285"/>
        <source>Download failed: %1.</source>
        <translation>下載失敗：%1。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="214"/>
        <source>Documentation info file is corrupt!</source>
        <translation>文件資訊檔已損毀！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="251"/>
        <source>Download failed: Downloaded file is corrupted.</source>
        <translation>下載失敗：下載的檔案已損毀。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="254"/>
        <source>Installing documentation %1...</source>
        <translation>安裝文件 %1 中...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.cpp" line="276"/>
        <source>Error while installing documentation:
%1</source>
        <translation>安裝文件時發生錯誤：
%1</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.ui" line="19"/>
        <source>Available Documentation:</source>
        <translation>可用的文件：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.ui" line="29"/>
        <source>Install</source>
        <translation>安裝</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.ui" line="36"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.ui" line="43"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.ui" line="63"/>
        <source>Installation Path:</source>
        <translation>安裝路徑：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/installdialog.ui" line="73"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="424"/>
        <source>Index</source>
        <translation>索引</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="422"/>
        <source>Contents</source>
        <translation>內容</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="426"/>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="428"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="777"/>
        <source>Qt Assistant</source>
        <translation>Qt 小幫手</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="272"/>
        <source>Unfiltered</source>
        <translation>未過濾</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="360"/>
        <source>File</source>
        <translation type="obsolete">檔案</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="354"/>
        <source>Page Set&amp;up...</source>
        <translation>頁面設定(&amp;U)...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="355"/>
        <source>Print Preview...</source>
        <translation>列印預覽...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="356"/>
        <source>&amp;Print...</source>
        <translation>列印(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="359"/>
        <source>CTRL+P</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="363"/>
        <source>New &amp;Tab</source>
        <translation>新增分頁(&amp;T)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="364"/>
        <source>CTRL+T</source>
        <translation>CTRL+T</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="365"/>
        <source>&amp;Close Tab</source>
        <translation>關閉分頁(&amp;C)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="366"/>
        <source>CTRL+W</source>
        <translation>CTRL+W</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="368"/>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="369"/>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="380"/>
        <source>Edit</source>
        <translation type="obsolete">編輯</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="373"/>
        <source>&amp;Copy selected Text</source>
        <translation>複製選取的文字(&amp;C)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="377"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="380"/>
        <source>&amp;Find in Text...</source>
        <translation>在文字中尋找(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="384"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="387"/>
        <source>Find &amp;Next</source>
        <translation>尋找下一筆(&amp;N)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="389"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="392"/>
        <source>Find &amp;Previous</source>
        <translation>尋找前一筆(&amp;P)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="394"/>
        <source>Shift+F3</source>
        <translation>Shift+F3</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="398"/>
        <source>Preferences...</source>
        <translation>喜好設定...</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="409"/>
        <source>View</source>
        <translation type="obsolete">檢視</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="402"/>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="406"/>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="408"/>
        <source>Zoom &amp;out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="412"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="414"/>
        <source>Normal &amp;Size</source>
        <translation>一般大小(&amp;S)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="418"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="423"/>
        <source>ALT+C</source>
        <translation>ALT+C</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="425"/>
        <source>ALT+I</source>
        <translation>ALT+I</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="435"/>
        <source>ALT+B</source>
        <translation type="obsolete">ALT+B</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="429"/>
        <source>ALT+S</source>
        <translation>ALT+S</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="439"/>
        <source>Go</source>
        <translation type="obsolete">前往</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="432"/>
        <source>&amp;Home</source>
        <translation>首頁(&amp;H)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="434"/>
        <source>Ctrl+Home</source>
        <translation>Ctrl+Home</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="438"/>
        <source>&amp;Back</source>
        <translation>返回(&amp;B)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="445"/>
        <source>&amp;Forward</source>
        <translation>往前(&amp;F)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="452"/>
        <source>Sync with Table of Contents</source>
        <translation>與目錄同步</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="459"/>
        <source>Next Page</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="460"/>
        <source>Ctrl+Alt+Right</source>
        <translation>Ctrl+Alt+Right</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="462"/>
        <source>Previous Page</source>
        <translation>前一頁</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="464"/>
        <source>Ctrl+Alt+Left</source>
        <translation>Ctrl+Alt+Left</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="467"/>
        <source>Add Bookmark...</source>
        <translation>新增書籤...</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="476"/>
        <source>CTRL+B</source>
        <translation type="obsolete">CTRL+B</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="478"/>
        <source>Help</source>
        <translation type="obsolete">說明</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="471"/>
        <source>About...</source>
        <translation>關於...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="474"/>
        <source>Navigation Toolbar</source>
        <translation>導覽工具列</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="543"/>
        <source>Toolbars</source>
        <translation>工具列</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="558"/>
        <source>Filter Toolbar</source>
        <translation>過濾器工具列</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="560"/>
        <source>Filtered by:</source>
        <translation>已過濾：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="581"/>
        <source>Address Toolbar</source>
        <translation>位址工具列</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="585"/>
        <source>Address:</source>
        <translation>位址：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="691"/>
        <source>Could not find the associated content item.</source>
        <translation>找不到相關的內容項目。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="751"/>
        <source>Open Source Edition</source>
        <translation>開放源碼版本</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="755"/>
        <source>This version of Qt Assistant is part of the Qt Open Source Edition, for use in the development of Open Source applications. Qt is a comprehensive C++ framework for cross-platform application development.</source>
        <translation>此版本的 Qt 小幫手是 Qt 開放源碼版本的一部份，只能用於開發開放源碼的應用程式。Qt 為一個跨平台的，強大的 C++ 應用程式開發框架。</translation>
    </message>
    <message>
        <location filename="../../tools/assistant/tools/assistant/mainwindow.cpp" line="753"/>
        <source>You need a commercial Qt license for development of proprietary (closed source) applications. Please see &lt;a href=&quot;http://www.trolltech.com/company/model.html&quot;&gt;www.trolltech.com/company/model.html&lt;/a&gt; for an overview of Qt licensing.</source>
        <translation type="obsolete">您需要商業版的 Qt 授權才能發展私有（封閉）應用程式軟體。關於 Qt 授權的概要，請參考 &lt;a href=&quot;http://www.trolltech.com/company/model.html&quot;&gt;www.trolltech.com/company/model.html&lt;/a&gt;。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="764"/>
        <source>This program is licensed to you under the terms of the Qt Commercial License Agreement. For details, see the file LICENSE that came with this software distribution.</source>
        <translation>此程式以 Qt 商業授權同意書（Qt Commerical License Agreement）授權給您。詳情請參照 LICENSE 檔。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="782"/>
        <source>About %1</source>
        <translation>關於 %1</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="900"/>
        <source>Updating search index</source>
        <translation>更新搜尋索引</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="293"/>
        <source>Looking for Qt Documentation...</source>
        <translation>搜尋 Qt 文件中...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="496"/>
        <source>&amp;Window</source>
        <translation>視窗(&amp;W)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="498"/>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="499"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="500"/>
        <source>Zoom</source>
        <translation>縮放</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="955"/>
        <source>Add</source>
        <translation type="obsolete">新增</translation>
    </message>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/mainwindow.cpp" line="963"/>
        <source>Remove</source>
        <translation type="obsolete">移除</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="758"/>
        <source>You need a commercial Qt license for development of proprietary (closed source) applications. Please see &lt;a href=&quot;http://trolltech.com/company/about/businessmodel&quot;&gt;http://trolltech.com/company/about/businessmodel&lt;/a&gt; for an overview of Qt licensing.</source>
        <translation>您需要商業版的 Qt 授權才能發展私有（封閉）應用程式軟體。關於 Qt 授權的概要，請參考 &lt;a href=&quot;http://trolltech.com/company/about/businessmodel&quot;&gt;http://trolltech.com/company/about/businessmodel&lt;/a&gt;。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="352"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="372"/>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="401"/>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="427"/>
        <source>ALT+O</source>
        <translation>ALT+O</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="431"/>
        <source>&amp;Go</source>
        <translation>前往(&amp;G)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="466"/>
        <source>&amp;Bookmarks</source>
        <translation>書籤(&amp;B)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="468"/>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/mainwindow.cpp" line="470"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../tools/assistant/tools/assistant/preferencesdialog.cpp" line="74"/>
        <source>From Local File System...</source>
        <translation type="obsolete">從本地檔案系統...</translation>
    </message>
    <message>
        <location filename="../../tools/assistant/tools/assistant/preferencesdialog.cpp" line="76"/>
        <source>Download from Help Server...</source>
        <translation type="obsolete">從說明伺服器下載...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.cpp" line="248"/>
        <source>Add Documentation</source>
        <translation>新增文件</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.cpp" line="235"/>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Qt 壓縮說明檔(*.qch)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.cpp" line="243"/>
        <source>The specified file is not a valid Qt Help File!</source>
        <translation>指定的檔案不是合法的 Qt 說明檔！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.cpp" line="249"/>
        <source>The namespace %1 is already registered!</source>
        <translation>命名空間 %1 已註冊！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.cpp" line="365"/>
        <source>Use custom settings</source>
        <translation>使用自訂設定</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="13"/>
        <source>Preferences</source>
        <translation>喜好設定</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="31"/>
        <source>Fonts</source>
        <translation>字型</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="45"/>
        <source>Font settings:</source>
        <translation>字型設定：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="53"/>
        <source>Browser</source>
        <translation>瀏覽器</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="58"/>
        <source>Application</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="94"/>
        <source>Filters</source>
        <translation>過濾器</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="100"/>
        <source>Filter:</source>
        <translation>過濾：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="110"/>
        <source>Attributes:</source>
        <translation>屬性：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="121"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="129"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="191"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="152"/>
        <source>Documentation</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="158"/>
        <source>Registered Documentation:</source>
        <translation>已註冊文件：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="184"/>
        <source>Add...</source>
        <translation>新增...</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="224"/>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="230"/>
        <source>Use Http Proxy</source>
        <translation>使用 Http 代理伺服器</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="242"/>
        <source>Http Proxy:</source>
        <translation>Http 代理伺服器：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/preferencesdialog.ui" line="252"/>
        <source>Port:</source>
        <translation>連接埠：</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../../../home/qiliang/depot/qt/4.4/tools/assistant/tools/assistant/bookmarkwidget.cpp" line="43"/>
        <source>New Folder</source>
        <translation type="obsolete">新資料夾</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="81"/>
        <source>The specified collection file does not exist!</source>
        <translation>指定的收集檔不存在！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="85"/>
        <source>Missing collection file!</source>
        <translation>遺失收集檔！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="94"/>
        <source>Invalid URL!</source>
        <translation>不合法的網址！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="98"/>
        <source>Missing URL!</source>
        <translation>遺失網址！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="153"/>
        <source>Unknown widget: %1</source>
        <translation>未知的元件：%1</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="157"/>
        <source>Missing widget!</source>
        <translation>遺失元件！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="176"/>
        <source>The specified Qt help file does not exist!</source>
        <translation>指定的 Qt 說明檔不存在！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="181"/>
        <source>Missing help file!</source>
        <translation>遺失說明檔！</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="191"/>
        <source>Unknown option: %1</source>
        <translation>未知的選項：%1</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/cmdlineparser.cpp" line="223"/>
        <source>Qt Assistant</source>
        <translation>Qt 小幫手</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/main.cpp" line="57"/>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>無法註冊文件檔
%1

理由：
%2</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/main.cpp" line="60"/>
        <source>Documentation successfully registered.</source>
        <translation>文件已註冊成功。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/main.cpp" line="67"/>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>無法解除註冊文件檔
%1

理由：
%2</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/main.cpp" line="70"/>
        <source>Documentation successfully unregistered.</source>
        <translation>文件已成功解除註冊。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/main.cpp" line="81"/>
        <source>The specified collection file could not be read!</source>
        <translation>指定的收集檔無法讀取。</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/bookmarkmanager.cpp" line="598"/>
        <source>Bookmark</source>
        <translation>書籤</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/remotecontrol.cpp" line="130"/>
        <source>Debugging Remote Control</source>
        <translation>遠端除錯控制</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/remotecontrol.cpp" line="131"/>
        <source>Received Command: %1 %2</source>
        <translation>已接收指令：%1 %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/searchwidget.cpp" line="146"/>
        <source>&amp;Copy</source>
        <translation>複製(&amp;C)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/searchwidget.cpp" line="149"/>
        <source>Copy &amp;Link Location</source>
        <translation>複製連結位置(&amp;L)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/searchwidget.cpp" line="188"/>
        <source>Open Link in New Tab</source>
        <translation>在新分頁開啟連結</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/searchwidget.cpp" line="160"/>
        <source>Select All</source>
        <translation>全部選取</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/searchwidget.cpp" line="187"/>
        <source>Open Link</source>
        <translation>開啟連結</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <location filename="../tools/assistant/tools/assistant/topicchooser.cpp" line="26"/>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>選擇 %1 的標題：</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/topicchooser.ui" line="16"/>
        <source>Choose Topic</source>
        <translation>選擇標題</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/topicchooser.ui" line="37"/>
        <source>&amp;Topics</source>
        <translation>標題(&amp;T)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/topicchooser.ui" line="88"/>
        <source>&amp;Display</source>
        <translation>顯示(&amp;D)</translation>
    </message>
    <message>
        <location filename="../tools/assistant/tools/assistant/topicchooser.ui" line="104"/>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
</context>
</TS>
